pm4py.streaming.algo.conformance.tbr package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.streaming.algo.conformance.tbr.variants

Submodules
----------

pm4py.streaming.algo.conformance.tbr.algorithm module
-----------------------------------------------------

.. automodule:: pm4py.streaming.algo.conformance.tbr.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.streaming.algo.conformance.tbr
   :members:
   :undoc-members:
   :show-inheritance:
